@@ -27,7 +27,7 @@ use constant  AWS_CONTAINER_CREDENTIALS_URL          => 'http://169.254.170.2';
 
 use vars qw/$VERSION @EXPORT/;
 
-$VERSION = '1.0.10-1'; $VERSION=~s/\-.*$//;
+$VERSION = '1.0.10-2'; $VERSION=~s/\-.*$//;
 
 @EXPORT = qw/$VERSION/;
 
@@ -100,7 +100,7 @@ default logger will output debug messages to STDERR.
 
 =item user_agent
 
-Pass in your own user agent, otherwise LWP will be used. I<Probably
+Pass in your own user agent, otherwise LWP will be used. I<Probably>
 only useful to override this for testing purposes.>
 
 =item profile
@@ -126,18 +126,18 @@ Example:
 
   my $creds = new Amazon::Credentials( { order => [ qw/file env role/] });
 
-=over 5
+=over 10
 
 =item env - Environment
 
 If there exists an environment variable $AWS_PROFILE, then an attempt
 will be made to retrieve credentials from the credentials file using
-that profile, otherwise we'll look for these environment variables to
-provide credentials.
+that profile, otherwise the class will for these environment variables
+to provide credentials.
 
-C<AWS_ACCESS_KEY_ID>
-C<AWS_SECRET_ACCESS_KEY>
-C<AWS_SESSION_TOKEN>
+ AWS_ACCESS_KEY_ID
+ AWS_SECRET_ACCESS_KEY
+ AWS_SESSION_TOKEN
 
 I<Note that when you set the environment variable AWS_PROFILE, the
 order essentially is overridden and we'll look in your credential
@@ -145,7 +145,7 @@ files (F<~/.aws/config>, F<~/.aws/credentials>) for your credentials.
 
 =item file - Configuration Files
 
-=over 10
+=over 15
 
 =item ~/.aws/config
 
@@ -155,7 +155,7 @@ files (F<~/.aws/config>, F<~/.aws/credentials>) for your credentials.
 
 The class will attempt to find the credentials in either of these two
 files.  You can also specify a profile to use for looking up the
-credentials by passing it into the constructor or setting in an the
+credentials by passing it into the constructor or setting it the
 environment variable C<AWS_PROFILE>.  If no profile is provided, the
 default credentials or the first profile found is used.
 
@@ -167,7 +167,7 @@ If the process is running in a container, the container may have a
 task role.  We'll look credentials using the container metadata
 service.
 
- http://169.254.170.2$AWS_CONTAINER_CREDENTIALS_RELATIVE_URI
+ http://169.254.170.2/$AWS_CONTAINER_CREDENTIALS_RELATIVE_URI
 
 =item role - Instance Role
 
@@ -175,10 +175,10 @@ The class will use the
 I<http://169.254.169.254/latest/meta-data/iam/security-credential> URL
 to look for an instance role and credentials.
 
-Keep in mind that these credentials include a token that needs to be
-passed to Amazon APIs when using the credentials returned when using
-instance meta-data.  That token has an expiration and should be
-refreshed as required.
+Credentials returned by accessing the meta-data include a token that
+should be passed to Amazon APIs along with the access key and secret.
+That token has an expiration and should be refreshed before it
+expires.
 
  if ( $aws_creds->is_token_expired() ) {
    $aws_creds->refresh_token()
@@ -652,6 +652,12 @@ sub get_creds_from_container {
 
 Rob Lauer - <rlauer6@comcast.net>
 
+=head1 LICENSE
+
+(c) Copyright 2019 Robert C. Lauer. All rights reserved.  This module
+is free software. It may be used, redistributed and/or modified under
+the same terms as Perl itself.
+
 =cut
 
 1;
